@@ -532,12 +532,13 @@ void PreferencesForm::create_sqlide_page()
     
     {
       mforms::CheckBox *check= new_checkbox_option("DbSqlEditor:SafeUpdates");
-      check->set_text(_("Forbid UPDATE and DELETE statements without a WHERE clause (safe updates)"));
+      check->set_text(_("Forbid UPDATE and DELETE statements without a WHERE clause (safe updates). Requires a reconnection."));
       check->set_tooltip(_(
                            "Enables the SQL_SAFE_UPDATES option for the session, "
                            "preventing SELECT and DELETE statements to be executed if a WHERE "
                            "clause is not present. That will avoid some dangerous commands that "
-                           "would update or delete all rows in a table by accident."));
+                           "would update or delete all rows in a table by accident.\n"
+                           "Changing this option requires a reconnection (Query -> Reconnect to Server)"));
       vbox->add(check, false);
     }    
     
