@@ -1029,11 +1029,12 @@ willCloseTabViewItem:(NSTabViewItem*)tabViewItem
 
 - (void)searchString:(NSString*)text
 {
-  [[[self activeEditor] view] findAndHighlightText:text
-                                         matchCase:NO
-                                         wholeWord:NO
-                                          scrollTo:YES
-                                              wrap:YES];
+  [[[self activeEditor] view] findAndHighlightText: text
+                                         matchCase: NO
+                                         wholeWord: NO
+                                          scrollTo: YES
+                                              wrap: YES
+                                         backwards: NO];
 }
 
 //--------------------------------------------------------------------------------------------------
