@@ -548,41 +548,43 @@ static void call_search(WBMainWindow *mainWindow)
 static bool search_callback(const std::string &find, const std::string &replace_with,
                             mforms::SearchFlags flags, ScintillaView *editor)
 {
-  if (flags&mforms::SearchAll && flags&mforms::SearchDoReplace)
-  {    
-    for (;;)
-    {
-      [editor findAndHighlightText: [NSString stringWithCPPString:find]
-                         matchCase: (flags&mforms::SearchMatchCase)?YES:NO
-                         wholeWord: (flags&mforms::SearchMatchWholeWord)?YES:NO
-                          scrollTo: YES
-                              wrap: YES];
-      
-      NSRange selected = [editor selectedRange];
-      if (selected.length > 1)
-        [editor insertText: [NSString stringWithCPPString: replace_with]];
-      else
-        break;
-    }
+  bool doReplace = (flags & mforms::SearchDoReplace) != 0;
+  bool doAll = (flags & mforms::SearchAll) != 0;
+  bool matchCase = (flags & mforms::SearchMatchCase) != 0;
+  bool matchWholeWord = (flags & mforms::SearchMatchWholeWord) != 0;
+  bool backwards = (flags & mforms::SearchPrevious) != 0;
+  
+  // Searching all occurences without replacing them doesn't make sense so we force replace here
+  // if the SearchAll flag is set.
+  if (doAll)
+    doReplace = true;
+  
+  NSString* text = [NSString stringWithCPPString: find];
+  
+  if (doReplace)
+  {
+    [editor findAndReplaceText: text
+                        byText: [NSString stringWithCPPString: replace_with]
+                     matchCase: matchCase
+                     wholeWord: matchWholeWord
+                         doAll: doAll];
   }
   else
   {
-    if (flags&mforms::SearchDoReplace)
-    {
-      NSRange selected = [editor selectedRange];
-      if (selected.length > 1)
-        [editor insertText: [NSString stringWithCPPString: replace_with]];
-    }
-    else
-      [editor findAndHighlightText: [NSString stringWithCPPString:find]
-                         matchCase: (flags&mforms::SearchMatchCase)?YES:NO
-                         wholeWord: (flags&mforms::SearchMatchWholeWord)?YES:NO
-                          scrollTo: YES
-                              wrap: YES];
+    // Simply find and select the first hit starting from the current location in the editor.
+    [editor findAndHighlightText: text
+                       matchCase: matchCase
+                       wholeWord: matchWholeWord
+                        scrollTo: YES
+                            wrap: YES
+                       backwards: backwards];
   }
+  
   return false;
 }
 
+//--------------------------------------------------------------------------------------------------
+
 static void call_find_replace(wb::WBContextUI *wbui, bool no_replace)
 {
   id firstResponder = [[NSApp keyWindow] firstResponder];
@@ -604,6 +606,8 @@ static void call_find_replace(wb::WBContextUI *wbui, bool no_replace)
     NSBeep();
 }
 
+//--------------------------------------------------------------------------------------------------
+
 static bool validate_find_replace(wb::WBContextUI *wbui)
 {
   id firstResponder = [[NSApp keyWindow] firstResponder];
