@@ -433,14 +433,26 @@ namespace MySQL.GUI.Workbench
       if (!dbSqlEditorBE.sql_editor_will_close(dbSqlEditorBE.active_sql_editor_index()))
         e.canClose = false;
       else
+        // Temporarily disconnect our tab change handler to avoid unnecessary changes.
         editorTabControl.SelectedIndexChanged -= editorTabControl_SelectedIndexChanged;
     }
 
     void editorTabControl_TabClosed(object sender, MySQL.Controls.TabClosedEventArgs e)
     {
       RemoveSqlEditor(dbSqlEditorBE.active_sql_editor_index());
+
+      // Reconnect the tab change handler we disconnected in eidotrTabControl_TabClosing.
       editorTabControl.SelectedIndexChanged += new EventHandler(editorTabControl_SelectedIndexChanged);
-      dbSqlEditorBE.active_sql_editor_index(editorTabControl.SelectedIndex);
+
+      // If the last editor was closed create a new, empty one.
+      if (editorTabControl.TabPages.Count > 0)
+        dbSqlEditorBE.active_sql_editor_index(editorTabControl.SelectedIndex);
+      else
+      {
+        SqlEditor sqlEditor = AddSqlEditor("", -1);
+        dbSqlEditorBE.active_sql_editor_index(0);
+        ActiveControl = sqlEditor;
+      }
     }
 
     public void SearchText(String text)
