@@ -611,6 +611,18 @@ ValueRef PythonContext::from_pyobject(PyObject *object)
     return ValueRef();
   }
 
+  if (PyTuple_Check(object))
+  {
+    grt::BaseListRef list(_grt);
+    
+    for (Py_ssize_t c= PyTuple_Size(object), i= 0; i < c; i++)
+    {
+      PyObject *item= PyTuple_GetItem(object, i);
+      list.ginsert(from_pyobject(item));
+    }
+    return list;
+  }
+  
   if (PyList_Check(object))
   {
     grt::BaseListRef list(_grt);
