@@ -2087,6 +2087,7 @@ static std::string get_export_sql(db_mysql_CatalogRef cat,
         continue;
       
       //if(gen_drops)
+      if (!string_from_map(user, drop_map).empty())
       {
         out_sql.append(string_from_map(user, drop_map)).append(";\n");
         if(show_warnings)
@@ -2236,6 +2237,7 @@ int DbMySQLImpl::makeSQLSyncScript(const grt::DictRef& options,
 std::string DbMySQLImpl::makeAlterScriptForObject(GrtNamedObjectRef source, GrtNamedObjectRef target, GrtNamedObjectRef obj)
 {
   grt::DbObjectMatchAlterOmf omf;
+  omf.dontdiff_mask = 5;
 
   DictRef options(get_grt());
   DictRef result(get_grt());
@@ -2366,6 +2368,7 @@ std::string DbMySQLImpl::makeAlterScriptForObject(GrtNamedObjectRef source, GrtN
 std::string DbMySQLImpl::makeCreateScriptForObject(GrtNamedObjectRef object)
 {
   grt::DbObjectMatchRecreateOmf omf;
+  omf.dontdiff_mask = 3;
 
   DictRef options(get_grt());
   DictRef result(get_grt());
