@@ -573,23 +573,33 @@ int WbModelImpl::createDiagramWithCatalog(workbench_physical_ModelRef model, db_
   if (object_count > 250)
     throw logic_error("Cannot create diagram: too many objects to place.");
 
+  DictRef wb_options= DictRef::cast_from(get_grt()->get("/wb/options/options"));
+  
   begin_undo_group();
   workbench_physical_DiagramRef diagram= create_view_for_object_count(model, object_count);
 
   for (size_t n= 0, count= schemata.count(); n < count; ++n)
   {
     db_SchemaRef schema= schemata[n];
+    model_FigureRef figure;
+    
     GRTLIST_FOREACH(db_Table, schema->tables(), table)
     {
-      diagram->placeTable(*table, 0.0, 0.0);
+      figure= diagram->placeTable(*table, 0.0, 0.0);
+      if (figure.is_valid())
+        figure->color(wb_options.get_string(figure.class_name()+":Color"));
     }
     GRTLIST_FOREACH(db_View, schema->views(), view)
     {
-      diagram->placeView(*view, 0.0, 0.0);
+      figure= diagram->placeView(*view, 0.0, 0.0);
+      if (figure.is_valid())
+        figure->color(wb_options.get_string(figure.class_name()+":Color"));
     }
     GRTLIST_FOREACH(db_RoutineGroup, schema->routineGroups(), rg)
     {
-      diagram->placeRoutineGroup(*rg, 0.0, 0.0);
+      figure= diagram->placeRoutineGroup(*rg, 0.0, 0.0);
+      if (figure.is_valid())
+        figure->color(wb_options.get_string(figure.class_name()+":Color"));
     }    
     autoplace_relations(diagram, schema->tables());
   }
@@ -612,7 +622,10 @@ int WbModelImpl::do_autoplace_any_list(const model_DiagramRef &view, ListRef<Grt
   
   workbench_physical_DiagramRef diagram(workbench_physical_DiagramRef::cast_from(view));
 
+  DictRef wb_options= DictRef::cast_from(get_grt()->get("/wb/options/options"));
+  
   GrtObjectRef object;
+  model_FigureRef figure;
   model_LayerRef layer= view->rootLayer();
 
   for (size_t n= 0; n < count; ++n)
@@ -621,18 +634,20 @@ int WbModelImpl::do_autoplace_any_list(const model_DiagramRef &view, ListRef<Grt
 
     if (object.is_instance("db.Table"))
     {
-      diagram->placeTable(db_TableRef::cast_from(object), 0.0, 0.0);
+      figure = diagram->placeTable(db_TableRef::cast_from(object), 0.0, 0.0);
     }
     else if (object.is_instance("db.View"))
     {
-      diagram->placeView(db_ViewRef::cast_from(object), 0.0, 0.0);
+      figure = diagram->placeView(db_ViewRef::cast_from(object), 0.0, 0.0);
     }
     else if (object.is_instance("db.RoutineGroup"))
     {
-      diagram->placeRoutineGroup(db_RoutineGroupRef::cast_from(object), 0.0, 0.0);
+      figure = diagram->placeRoutineGroup(db_RoutineGroupRef::cast_from(object), 0.0, 0.0);
     }
     else
       continue;
+    if (figure.is_valid())
+      figure->color(wb_options.get_string(figure.class_name()+":Color"));
   }
 
   return 0;
