@@ -310,6 +310,7 @@ class WbAdminControl:
     def __init__(self, server_profile,
                             connect_sql=True):
 
+        self.server_control = None
         self.events   = EventManager()
         self.defer_events() # continue events should be called when all listeners are registered, that happens later in the caller code
                           # Until then events are piled in the queue
@@ -399,15 +400,25 @@ class WbAdminControl:
             else:
                 dprint_ex(1, "uses_ssh: %i uses_wmi: %i" % (self.server_profile.uses_ssh, self.server_profile.uses_wmi))
                 raise Exception("Unknown management method selected. Server Profile is possibly inconsistent")
-    
-    
+
+
     def shutdown(self):
         self.events.event('shutdown')
         self.running = False
         self.disconnect_sql()
 
     #---------------------------------------------------------------------------
+    def is_server_running(self, verbose = 0):
+      # Perform SQL ping if ping fails run self.server_control.get_status()
+      ret = "unknown"
+      if self.sql_ping() == True:
+        ret = "running"
+      else:
+        ret = self.server_control.get_status(verbose=verbose)
 
+      return ret
+
+    #---------------------------------------------------------------------------
     def uitask(self, task, *args):
         self.task_queue.put((task, args))
 
@@ -525,6 +536,27 @@ class WbAdminControl:
         dprint_ex(2, "ret = ", ret)
         return ret
 
+    #---------------------------------------------------------------------------
+    def sql_ping(self):
+      ret = False
+      if self.sql and self.sql.is_connected():
+        try:
+          self.sql.exec_query("select 1")
+          ret = True
+        except QueryError, e:
+          if not e.is_connection_error():
+            ret = True # Any other error except connection ones is from server
+      else:
+        try:
+          self.connect_sql()
+        except MySQLError, e:
+          pass # ignore connection errors, since it likely means the server is down
+
+        # Do not do anything for now, connection status check will be perfomed
+        # on the next sql_ping call
+      return ret
+
+    #---------------------------------------------------------------------------
     def exec_query(self, q):
         ret = None
         if self.sql is not None:
@@ -538,6 +570,8 @@ class WbAdminControl:
                     if e.is_error_recoverable():
                         dprint_ex(1, "Error is recoverable. Reconnecting to MySQL server.")
                         self.connect_sql()
+                else: # if exception is not handled, give a chance to the caller do it
+                    raise e
         else:
             dprint_ex(1,"sql connection is down")
 
@@ -556,6 +590,8 @@ class WbAdminControl:
             if e.is_error_recoverable():
               dprint_ex(1, "Error is recoverable. Reconnecting to MySQL server.")
               self.connect_sql()
+          else:
+            raise e
       else:
         dprint_ex(1,"sql connection is down")
 
