@@ -10,13 +10,12 @@ import mforms
 from wb_server_management import wbaOS
 from wb_common import OperationCancelledError, InvalidPasswordError, dprint_ex
 
-import subprocess
 import re
 import socket
 
 #-------------------------------------------------------------------------------
 def get_local_ip_list():
-    cmd    = "ifconfig"
+    cmd    = "/bin/sh -c ifconfig"
     regexp = "inet addr:([0-9a-f:\.]+)"
 
     if hasattr(sys, 'getwindowsversion'):
@@ -25,16 +24,27 @@ def get_local_ip_list():
     elif 'darwin' in sys.platform:
         regexp = "inet ([0-9a-f\.:]+) netmask"
 
-    result = subprocess.Popen(cmd, stdout=subprocess.PIPE).communicate()[0]
-    m = re.findall(regexp, result)
+    out = None
+    try:
+      out = os.popen(cmd)
+    except Exception, e:
+      # We do not care if execution failed, the list will just be empty
+      print e
+      out = None
+    except:
+      print "Unknown exception while running '%s'"%cmd
 
     ret = []
-    for ip in m:
-        try:
-            t_ip = socket.gethostbyname(ip)
-            ret.append(ip)
-        except socket.gaierror,e:
-            print ip, str(e)
+    if out:
+        result = out.read()
+        m = re.findall(regexp, result)
+
+        for ip in m:
+            try:
+                t_ip = socket.gethostbyname(ip)
+                ret.append(ip)
+            except socket.gaierror,e:
+                print ip, str(e)
     return ret
 
 local_ip_list = get_local_ip_list()
