@@ -188,7 +188,7 @@ class WBAWinRemoteStats:
     self.cpu_widget = cpu_widget
     self.mem_widget = mem_widget
     self.settings = server_profile
-    self.remote_admin_enabled = int(self.settings.serverInfo["remoteAdmin"]) != 0
+    self.remote_admin_enabled = self.settings.uses_ssh
 
     if not self.remote_admin_enabled:
       return
@@ -441,16 +441,19 @@ class WBAWinLocalStats:
       line += c
       if c == "\n":
         line = line.strip(" \r\t\n%")
-        if line[0] == 'C':
-          self.mtx.acquire()
-          self.cpu = line[2:]
-          self.mtx.release()
-        elif line[0] == 'M':
-          self.mtx.acquire()
-          self.mem = line[2:]
-          self.mtx.release()
-        line = ""
-        dprint_ex(4, "WinLocalStats: line-", line, ", cpu-", self.cpu, ", mem", self.mem)
+        if len(line) == 0:
+          print "Read empty string from script" # TODO: Probably need another way of informing. TBD
+        else:
+          if line[0] == 'C':
+            self.mtx.acquire()
+            self.cpu = line[2:]
+            self.mtx.release()
+          elif line[0] == 'M':
+            self.mtx.acquire()
+            self.mem = line[2:]
+            self.mtx.release()
+          line = ""
+          dprint_ex(4, "WinLocalStats: line-", line, ", cpu-", self.cpu, ", mem", self.mem)
 
   #-----------------------------------------------------------------------------
   def get_cpu(self):
