@@ -59,7 +59,7 @@ class WbAdminConfigFileUI(TabView):
       self.file_name_ctrl = file_name_ctrl
       self.file_name_ctrl.set_enabled(False)
       self.section_ctrl = section_ctrl
-      self.cfg_be = None
+      self.cfg_be = None # Will be created later in self.create_ui
       self.version = version
 
     #---------------------------------------------------------------------------
@@ -74,6 +74,7 @@ class WbAdminConfigFileUI(TabView):
         self.loading = False
         return
 
+      # page is a stored page data stored in self.pages in create_ui
       page = self.pages[page_number]
       if page.created == True:
         self.loading = False
@@ -85,6 +86,7 @@ class WbAdminConfigFileUI(TabView):
       box.set_spacing(8)
       box.suspend_layout()
 
+      # Actual option values from config file parsed by cfg_be, in form of list of tuples (<name>, <value>)
       options = self.cfg_be.get_options(self.section_ctrl.get_string_value())
       opts_map = dict(options)
 
@@ -124,10 +126,15 @@ class WbAdminConfigFileUI(TabView):
           # However if user config file contains alias, we substitute the alias 
           # instead of official option name to use for this WBA session. From now
           # on all operation with the option are done through alias.
-          for alias in (name.replace("-","_"), name.replace("_","-")):
-            if name != alias and alias in opts_map:
-              name = alias
-              ctrl_def['name'] = name
+          names = self.cfg_be.option_alt_names(name) #(name, name.replace("-","_"), name.replace("_","-"))
+          right_name = filter(lambda x: x in opts_map, names)
+          if len(right_name) > 0:
+            right_name = right_name[0]
+            caption = ctrl_def.get('caption')
+            if caption and name in caption:
+              ctrl_def['caption'] = caption.replace(name, right_name)
+            name = right_name
+            ctrl_def['name'] = name
 
           ctrl_tupple = self.place_control(ctrl_def, table, table_row)
 
@@ -137,7 +144,6 @@ class WbAdminConfigFileUI(TabView):
           label.set_style(SmallHelpTextStyle)
           table.add(label, 2, 3, table_row, table_row + 1, HFillFlag | VFillFlag)
 
-          #tag      = ctrl_tupple[0]
           ctrl     = ctrl_tupple[1]
           ctrl_def = ctrl_tupple[2]
 
@@ -167,6 +173,23 @@ class WbAdminConfigFileUI(TabView):
       box.resume_layout()
       self.loading = False
 
+    def locate_option(self, option_name_fragment):
+      ret = None
+      for opt in self.cfg_be.get_options_containing(option_name_fragment):
+        (tab_name, group_name) = self.cfg_be.get_option_location(opt)
+        if tab_name is not None:
+          for page_idx, page in self.pages.iteritems():
+            if page.page_name == tab_name:
+              self.create_page(page_idx)
+              self.set_active_tab(page_idx - 1)
+              page.panel.flush_events()
+              ctrl_tuple = self.opt2ctrl_map.get(opt)
+              # ctrl_tuple is in for of ('<type>', <ui controls tuple>, <opt def from xml file>)
+              if ctrl_tuple is not None:
+                ctrl = ctrl_tuple[1] # in this ctrl we have format of (enabled_checkbox, ...)
+                page.panel.scroll_to_view(ctrl[0]) # scroll to enabled checkbox
+                return
+
     def tab_changed(self):
       page_number = self.get_active_tab() + 1
       page = self.pages.get(page_number)
@@ -335,8 +358,8 @@ class WbAdminConfigFileUI(TabView):
         ctrl = ('chk', (enabled, enabled), ctrl_def)
         self.opt2ctrl_map[name] = ctrl
         enabled.set_active(False)
-        label = newLabel(" ")
-        table.add(label, 1, 2, row, row+1, HExpandFlag | HFillFlag)
+        #label = newLabel(" ")
+        #table.add(label, 1, 2, row, row+1, HExpandFlag | HFillFlag)
       elif ctype == 'textedit' or ctype == 'string' or ctype == 'set':
         te = self.create_textedit(name, ctrl_def)
         table.add(te, 1, 2, row, row+1, HExpandFlag | HFillFlag)
@@ -664,10 +687,27 @@ class WbAdminConfigFileUI(TabView):
 
       # each opt is (name, value)
       for name, value in self.cfg_be.get_options(self.section):
-        if self.opt2ctrl_map.has_key(name):
-          ctrl = self.opt2ctrl_map[name]
-          self.enabled_checkbox_click(name, True)
-          self.set_string_value_to_control(ctrl, value)
+        ctrl = self.opt2ctrl_map.get(name)
+        if not ctrl:
+          # We are here because of either 1) alias, or 2) unknown option, or 
+          # 3) initial load when map is not created
+          # Try to resolve alias and update UI and maps
+          names = self.cfg_be.option_alt_names(name)
+          for alt_name in names:
+            ctrl = self.opt2ctrl_map.get(alt_name)
+            if ctrl is not None:
+              # Fix UI and map
+              self.opt2ctrl_map[name] = ctrl
+              # Rename checkbox with name
+              ctrl[1][0].set_text(name)
+              del self.opt2ctrl_map[alt_name]
+              break
+
+        if ctrl is None:
+          continue
+
+        self.enabled_checkbox_click(name, True)
+        self.set_string_value_to_control(ctrl, value)
 
       self.loading = False
 
